==> jc-1.4.0.tar.gz: gnu/java/awt/Buffers.h <==
// public final class gnu.java.awt.Buffers

// class file dependencies
// @dep_class 81b491adbdb21524 gnu_java_awt_Buffers
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_Buffers_H_
#define _JC_gnu_java_awt_Buffers_H_

// Forward structure declarations
struct _jc_java_awt_image_DataBuffer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_awt_Buffers$sub_refs	_jc_gnu_java_awt_Buffers$sub_refs;
typedef struct _jc_gnu_java_awt_Buffers$sub_nonrefs	_jc_gnu_java_awt_Buffers$sub_nonrefs;
typedef struct _jc_gnu_java_awt_Buffers$refs	_jc_gnu_java_awt_Buffers$refs;
typedef struct _jc_gnu_java_awt_Buffers$nonrefs	_jc_gnu_java_awt_Buffers$nonrefs;
typedef struct _jc_gnu_java_awt_Buffers$object	_jc_gnu_java_awt_Buffers$object;

typedef const struct _jc_gnu_java_awt_Buffers$vmethods	_jc_gnu_java_awt_Buffers$vmethods;
typedef const struct _jc_gnu_java_awt_Buffers$vtable	_jc_gnu_java_awt_Buffers$vtable;
typedef const struct _jc_gnu_java_awt_Buffers$vtype	_jc_gnu_java_awt_Buffers$vtype;

// Constructors
extern void _jc_gnu_java_awt_Buffers$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_Buffers$object *);

// Static methods
extern struct _jc_java_awt_image_DataBuffer$object *_jc_gnu_java_awt_Buffers$method$createBuffer$d76239cb9507d291(_jc_env *, jint, jint);
extern struct _jc_java_awt_image_DataBuffer$object *_jc_gnu_java_awt_Buffers$method$createBuffer$e79dc6c8b58d2183(_jc_env *, jint, jint, jint);
extern struct _jc_java_awt_image_DataBuffer$object *_jc_gnu_java_awt_Buffers$method$createBuffer$d673d14c6a0ea4b5(_jc_env *, jint, struct _jc_java_lang_Object$object *, jint);
extern struct _jc_java_awt_image_DataBuffer$object *_jc_gnu_java_awt_Buffers$method$createBufferFromData$4c773188dc61281c(_jc_env *, jint, struct _jc_java_lang_Object$object *, jint);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_awt_Buffers$method$getData$55779909ba99f9cf(_jc_env *, struct _jc_java_awt_image_DataBuffer$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_awt_Buffers$method$getData$b40b3145976c22a6(_jc_env *, struct _jc_java_awt_image_DataBuffer$object *, jint, struct _jc_java_lang_Object$object *, jint, jint);
extern jint _jc_gnu_java_awt_Buffers$method$smallestAppropriateTransferType$81439c351e024e20(_jc_env *, jint);

// Virtual methods structure
struct _jc_gnu_java_awt_Buffers$vmethods {
};

// Vtable
struct _jc_gnu_java_awt_Buffers$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_Buffers$vmethods	gnu_java_awt_Buffers;
};

// Vtype
struct _jc_gnu_java_awt_Buffers$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_Buffers$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_Buffers$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_Buffers$refs {
    _jc_gnu_java_awt_Buffers$sub_refs	gnu_java_awt_Buffers;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_Buffers$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_Buffers$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_Buffers$sub_nonrefs	gnu_java_awt_Buffers;
};

// Object instance structure
struct _jc_gnu_java_awt_Buffers$object {
	_jc_gnu_java_awt_Buffers$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_Buffers$vtype	*vtype;
	_jc_gnu_java_awt_Buffers$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_Buffers$vtype _jc_gnu_java_awt_Buffers$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_Buffers, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_Buffers$class_object;

#endif	/* _JC_gnu_java_awt_Buffers_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/Buffers.h <==
// public final class gnu.java.awt.Buffers

// class file dependencies
// @dep_class db74ec318f7806c gnu_java_awt_Buffers
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_Buffers_H_
#define _JC_gnu_java_awt_Buffers_H_

// Forward structure declarations
struct _jc_java_awt_image_DataBuffer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_awt_Buffers$sub_refs	_jc_gnu_java_awt_Buffers$sub_refs;
typedef struct _jc_gnu_java_awt_Buffers$sub_nonrefs	_jc_gnu_java_awt_Buffers$sub_nonrefs;
typedef struct _jc_gnu_java_awt_Buffers$refs	_jc_gnu_java_awt_Buffers$refs;
typedef struct _jc_gnu_java_awt_Buffers$nonrefs	_jc_gnu_java_awt_Buffers$nonrefs;
typedef struct _jc_gnu_java_awt_Buffers$object	_jc_gnu_java_awt_Buffers$object;

typedef const struct _jc_gnu_java_awt_Buffers$vmethods	_jc_gnu_java_awt_Buffers$vmethods;
typedef const struct _jc_gnu_java_awt_Buffers$vtable	_jc_gnu_java_awt_Buffers$vtable;
typedef const struct _jc_gnu_java_awt_Buffers$vtype	_jc_gnu_java_awt_Buffers$vtype;

// Constructors
extern void _jc_gnu_java_awt_Buffers$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_Buffers$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_awt_image_DataBuffer$object *_jc_gnu_java_awt_Buffers$method$createBuffer$d76239cb9507d291(_jc_env *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_awt_image_DataBuffer$object *_jc_gnu_java_awt_Buffers$method$createBuffer$e79dc6c8b58d2183(_jc_env *, jint, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_awt_image_DataBuffer$object *_jc_gnu_java_awt_Buffers$method$createBuffer$d673d14c6a0ea4b5(_jc_env *, jint, struct _jc_java_lang_Object$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_awt_image_DataBuffer$object *_jc_gnu_java_awt_Buffers$method$createBufferFromData$4c773188dc61281c(_jc_env *, jint, struct _jc_java_lang_Object$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_awt_Buffers$method$getData$55779909ba99f9cf(_jc_env *, struct _jc_java_awt_image_DataBuffer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_awt_Buffers$method$getData$b40b3145976c22a6(_jc_env *, struct _jc_java_awt_image_DataBuffer$object *, jint, struct _jc_java_lang_Object$object *, jint, jint) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_Buffers$method$smallestAppropriateTransferType$81439c351e024e20(_jc_env *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_Buffers$vmethods {
};

// Vtable
struct _jc_gnu_java_awt_Buffers$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_Buffers$vmethods	gnu_java_awt_Buffers;
};

// Vtype
struct _jc_gnu_java_awt_Buffers$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_Buffers$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_Buffers$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_Buffers$refs {
    _jc_gnu_java_awt_Buffers$sub_refs	gnu_java_awt_Buffers;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_Buffers$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_Buffers$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_Buffers$sub_nonrefs	gnu_java_awt_Buffers;
};

// Object instance structure
struct _jc_gnu_java_awt_Buffers$object {
	_jc_gnu_java_awt_Buffers$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_Buffers$vtype	*vtype;
	_jc_gnu_java_awt_Buffers$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_Buffers$vtype _jc_gnu_java_awt_Buffers$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_Buffers, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_Buffers$class_object;

#endif	/* _JC_gnu_java_awt_Buffers_H_ */
